package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.FollowInfo;

/**
 * 关注信息Service接口
 * 
 * @author haotian
 * @date 2024-12-26
 */
public interface IFollowInfoService 
{
    /**
     * 查询关注信息
     * 
     * @param followInfoId 关注信息主键
     * @return 关注信息
     */
    public FollowInfo selectFollowInfoByFollowInfoId(Long followInfoId);

    /**
     * 查询关注信息列表
     * 
     * @param followInfo 关注信息
     * @return 关注信息集合
     */
    public List<FollowInfo> selectFollowInfoList(FollowInfo followInfo);

    /**
     * 新增关注信息
     * 
     * @param followInfo 关注信息
     * @return 结果
     */
    public int insertFollowInfo(FollowInfo followInfo);

    /**
     * 修改关注信息
     * 
     * @param followInfo 关注信息
     * @return 结果
     */
    public int updateFollowInfo(FollowInfo followInfo);

    /**
     * 批量删除关注信息
     * 
     * @param followInfoIds 需要删除的关注信息主键集合
     * @return 结果
     */
    public int deleteFollowInfoByFollowInfoIds(Long[] followInfoIds);

    /**
     * 删除关注信息信息
     * 
     * @param followInfoId 关注信息主键
     * @return 结果
     */
    public int deleteFollowInfoByFollowInfoId(Long followInfoId);
}
